tomita.legacy package
=====================

Submodules
----------

tomita.legacy.demosongs module
------------------------------

.. automodule:: tomita.legacy.demosongs
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.menv module
-------------------------

.. automodule:: tomita.legacy.menv
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.mixfiles module
-----------------------------

.. automodule:: tomita.legacy.mixfiles
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.mkfreq module
---------------------------

.. automodule:: tomita.legacy.mkfreq
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.nokiacomposer2wav module
--------------------------------------

.. automodule:: tomita.legacy.nokiacomposer2wav
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.play\_wav module
------------------------------

.. automodule:: tomita.legacy.play_wav
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.pysynth module
----------------------------

.. automodule:: tomita.legacy.pysynth
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.pysynth\_b module
-------------------------------

.. automodule:: tomita.legacy.pysynth_b
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.pysynth\_beeper module
------------------------------------

.. automodule:: tomita.legacy.pysynth_beeper
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.pysynth\_c module
-------------------------------

.. automodule:: tomita.legacy.pysynth_c
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.pysynth\_d module
-------------------------------

.. automodule:: tomita.legacy.pysynth_d
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.pysynth\_e module
-------------------------------

.. automodule:: tomita.legacy.pysynth_e
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.pysynth\_p module
-------------------------------

.. automodule:: tomita.legacy.pysynth_p
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.pysynth\_s module
-------------------------------

.. automodule:: tomita.legacy.pysynth_s
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.pysynth\_samp module
----------------------------------

.. automodule:: tomita.legacy.pysynth_samp
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.read\_abc module
------------------------------

.. automodule:: tomita.legacy.read_abc
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.readmidi module
-----------------------------

.. automodule:: tomita.legacy.readmidi
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.setup module
--------------------------

.. automodule:: tomita.legacy.setup
    :members:
    :undoc-members:
    :show-inheritance:

tomita.legacy.test\_nokiacomposer2wav module
--------------------------------------------

.. automodule:: tomita.legacy.test_nokiacomposer2wav
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: tomita.legacy
    :members:
    :undoc-members:
    :show-inheritance:
